aboutsummaryrefslogtreecommitdiff
path: root/pci-arbiter/pcifs.h
diff options
context:
space:
mode:
Diffstat (limited to 'pci-arbiter/pcifs.h')
-rw-r--r--pci-arbiter/pcifs.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/pci-arbiter/pcifs.h b/pci-arbiter/pcifs.h
index ba16ebaa..18f2141c 100644
--- a/pci-arbiter/pcifs.h
+++ b/pci-arbiter/pcifs.h
@@ -135,14 +135,14 @@ struct pcifs_perm
int32_t gid;
};
-/* Various parameters that can be used to change the behavior of an ftpfs. */
+/* Various parameters that can be used to change the behavior of a pcifs. */
struct pcifs_params
{
/* The size of the node cache. */
size_t node_cache_max;
- /* Bootstrap disk server task */
- mach_port_t disk_server_task;
+ /* Next bootstrap task */
+ mach_port_t next_task;
/* FS permissions. */
struct pcifs_perm *perms;